@@ -1,13 +1,8 @@
 {-# LANGUAGE CPP #-}
 module Data.String.Interpolate.Compat (
   readMaybe
-, module Language.Haskell.TH
-#if !MIN_VERSION_template_haskell(2,8,0)
-, reportError
-#endif
 ) where
 
-import           Language.Haskell.TH
 import           Text.Read
 
 #if !MIN_VERSION_base(4,6,0)
@@ -37,8 +32,3 @@ readMaybe s = case readEither s of
                 Left _  -> Nothing
                 Right a -> Just a
 #endif
-
-#if !MIN_VERSION_template_haskell(2,8,0)
-reportError :: String -> Q ()
-reportError = report True
-#endif
